"""Configuration for {{ project_name }}."""

from __future__ import annotations

from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    model_name: str = "{{ model_name }}"
    system_prompt: str = "You are a helpful assistant."
    cors_origins: list[str] = ["*"]

    # Provider API keys (loaded from environment / .env)
    openai_api_key: str = ""
    claude_api_key: str = ""
    google_api_key: str = ""

    model_config = {"env_file": ".env", "env_file_encoding": "utf-8"}


settings = Settings()
